@@ -1,10 +1,10 @@
 arch_get_kernel_flavour () {
 	case "$SUBARCH" in
-	    iop32x|iop33x|ixp4xx|orion5x|versatile)
+	    iop32x|iop33x|ixp4xx|kirkwood|orion5x|versatile)
 		echo "$SUBARCH"
 		return 0 ;;
 	    ads)
-		# NOTE: this kernel is not in Debian (sarge), but makes it
+		# NOTE: this kernel is not in Debian, but makes it
 		# easier to offer unofficial support from a private apt-archive
 		echo "ads"
 		return 0 ;;
@@ -22,7 +22,7 @@ arch_check_usable_kernel () {
 
 arch_get_kernel () {
 	case "$KERNEL_MAJOR" in
-	    2.6)
+	    2.6|3.*)
 		case "$1" in
 		    bast)
 			echo "linux-image-$KERNEL_MAJOR-s3c2410"
