@@ -16,8 +16,9 @@ DISTRIBUTION=
 # used by kernel installation code
 KERNEL=
 KERNEL_LIST=/tmp/available_kernels.txt
-case `udpkg --print-os` in
-	linux)		KERNEL_MAJOR="$(uname -r | cut -d . -f 1,2)" ;;
+KERNEL_NAME=`udpkg --print-os`
+case $KERNEL_NAME in
+	linux)		KERNEL_MAJOR="$(uname -r | cut -d - -f 1 | cut -d . -f 1,2)" ;;
 	kfreebsd)	KERNEL_MAJOR="$(uname -r | cut -d . -f 1)" ;;
 	hurd)		KERNEL_MAJOR="$(uname -v | cut -d ' ' -f 2 | cut -d . -f 1)" ;;
 esac
@@ -32,6 +33,7 @@ CPUINFO=/proc/cpuinfo
 APT_SOURCES=/target/etc/apt/sources.list
 APT_CONFDIR=/target/etc/apt/apt.conf.d
 IT_CONFDIR=/target/etc/initramfs-tools/conf.d
+DPKG_CONFDIR=/target/etc/dpkg/dpkg.cfg.d
 
 IFS_ORIG="$IFS"
 NL="
@@ -170,6 +172,13 @@ APT::Get::AllowUnauthenticated "true";
 Aptitude::CmdLine::Ignore-Trust-Violations "true";
 EOT
 	fi
+
+	# Disable all syncing; it's unnecessary in an installation context,
+	# and can slow things down quite a bit.
+	# This file will be left in place until the end of the install.
+	cat > $DPKG_CONFDIR/force-unsafe-io <<EOT
+force-unsafe-io
+EOT
 }
 
 final_apt_preferences () {
@@ -325,7 +334,7 @@ get_mirror_info () {
 
 kernel_update_list () {
 	# Use 'uniq' to avoid listing the same kernel more then once
-	chroot /target apt-cache search '^(kernel|linux|kfreebsd|gnumach)-image' | \
+	chroot /target apt-cache search "^(kernel|$KERNEL_NAME)-image" | \
 	cut -d" " -f1 | uniq > "$KERNEL_LIST.unfiltered"
 	kernels=`sort -r "$KERNEL_LIST.unfiltered" | tr '\n' ' ' | sed -e 's/ $//'`
 	for candidate in $kernels; do
@@ -463,6 +472,11 @@ install_kernel_linux () {
 	target_kernel_major="$(echo "$KERNEL" | sed 's/^kernel-image-//; s/^linux-image-//; s/-.*//' | cut -d . -f 1,2)"
 	case $target_kernel_major in
 		2.?)	;;
+		[3-9].*)
+			# As far as our debconf templates are concerned,
+			# this is essentially 2.6.
+			target_kernel_major=2.6
+			;;
 		*)
 			# something went wrong; use major version of
 			# installation kernel
